==> nui_database-0.0.9.tar.gz: lib/models/enums/nui_database_query_type.dart <==
import 'package:nui_core/nui_core.dart';
import 'package:nui_database/models/enums/nui_database_data_type.dart';
import 'package:nui_database/models/nui_database_entity_field.dart';

enum NUIDBQueryType{
  EQUALS,
  MORE_THAN,
  MORE_THAN_EQUAL_TO,
  LESS_THAN,
  LESS_THAN_EQUAL_TO,
  NOT_EQUAL,
  IS_NULL,
  IS_NOT_NULL,
  LIKE,
  IN
}

extension NUIDBQueryTypeExt on NUIDBQueryType{
  String value(){
    switch(this){
      case NUIDBQueryType.EQUALS : return "=";
      case NUIDBQueryType.LESS_THAN : return "<";
      case NUIDBQueryType.LESS_THAN_EQUAL_TO : return "<=";
      case NUIDBQueryType.MORE_THAN : return ">";
      case NUIDBQueryType.MORE_THAN_EQUAL_TO : return ">=";
      case NUIDBQueryType.NOT_EQUAL : return "!=";
      case NUIDBQueryType.IS_NULL : return "IS NULL";
      case NUIDBQueryType.IS_NOT_NULL : return "IS NOT NULL";
      case NUIDBQueryType.LIKE : return "LIKE";
      case NUIDBQueryType.IN : return "IN";
    }
    throw Exception("NUIDatabase -> Invalid query type");
  }

  bool hasArgument(){
    switch(this){
      case NUIDBQueryType.IS_NULL :
      case NUIDBQueryType.IS_NOT_NULL :
      case NUIDBQueryType.IN :
        return false;
      default: return true;
    }
  }

  dynamic argument(dynamic value){
    switch(this){
      case NUIDBQueryType.LIKE :
        return "%$value%";
      default:
        return value;
    }
  }

  String query(NUIDBField field, dynamic value){
    String fieldName = field.name;
    NUIEntType dataType = field.type;
    NUIDBNativeType nativeType = dataType.native();
    String queryType = this.value();

    switch(this){
      case NUIDBQueryType.EQUALS :
      case NUIDBQueryType.LESS_THAN :
      case NUIDBQueryType.LESS_THAN_EQUAL_TO :
      case NUIDBQueryType.MORE_THAN :
      case NUIDBQueryType.MORE_THAN_EQUAL_TO :
      case NUIDBQueryType.NOT_EQUAL :
      case NUIDBQueryType.LIKE :
        return "$fieldName $queryType ?";
      case NUIDBQueryType.IS_NULL :
      case NUIDBQueryType.IS_NOT_NULL :
        return "$fieldName $queryType";
      case NUIDBQueryType.IN : {
        if(!value is List) throw Exception("NUIDatabase -> Invalid like query data type");

        List values = value as List;
        String query = "$fieldName $queryType (";
        bool isText = nativeType == NUIDBNativeType.TEXT;
        String inQuery = "";
        for(dynamic d in values){
          if(inQuery.isEmpty){
            inQuery = inQuery + (isText ? "'$d'" : "$d");
          }
          else{
            inQuery = inQuery + ", " + (isText ? "'$d'" : "$d");
          }
        }
        query = query + inQuery + ")";
        return query;
      }
    }
    throw Exception("NUIDatabase -> Invalid query type");
  }
}

==> nui_database-0.0.12.tar.gz: lib/models/enums/nui_database_query_type.dart <==
import 'package:nui_core/nui_core.dart';
import 'package:nui_database/models/enums/nui_database_data_type.dart';
import 'package:nui_database/models/nui_database_entity_field.dart';

enum NUIDBQueryType{
  EQUALS,
  MORE_THAN,
  MORE_THAN_EQUAL_TO,
  LESS_THAN,
  LESS_THAN_EQUAL_TO,
  NOT_EQUAL,
  IS_NULL,
  IS_NOT_NULL,
  LIKE,
  IN
}

extension NUIDBQueryTypeExt on NUIDBQueryType{
  String value(){
    switch(this){
      case NUIDBQueryType.EQUALS : return "=";
      case NUIDBQueryType.LESS_THAN : return "<";
      case NUIDBQueryType.LESS_THAN_EQUAL_TO : return "<=";
      case NUIDBQueryType.MORE_THAN : return ">";
      case NUIDBQueryType.MORE_THAN_EQUAL_TO : return ">=";
      case NUIDBQueryType.NOT_EQUAL : return "!=";
      case NUIDBQueryType.IS_NULL : return "IS NULL";
      case NUIDBQueryType.IS_NOT_NULL : return "IS NOT NULL";
      case NUIDBQueryType.LIKE : return "LIKE";
      case NUIDBQueryType.IN : return "IN";
    }
    throw Exception("NUIDatabase -> Invalid query type");
  }

  bool hasArgument(){
    switch(this){
      case NUIDBQueryType.IS_NULL :
      case NUIDBQueryType.IS_NOT_NULL :
      case NUIDBQueryType.IN :
        return false;
      default: return true;
    }
  }

  dynamic argument(dynamic value){
    switch(this){
      case NUIDBQueryType.LIKE :
        return "%$value%";
      default:
        return value;
    }
  }

  String query(NUIDBField field, dynamic value){
    String fieldName = field.name;
    NUIEntType dataType = field.type;
    NUIDBNativeType nativeType = dataType.native();
    String queryType = this.value();

    switch(this){
      case NUIDBQueryType.EQUALS :
      case NUIDBQueryType.LESS_THAN :
      case NUIDBQueryType.LESS_THAN_EQUAL_TO :
      case NUIDBQueryType.MORE_THAN :
      case NUIDBQueryType.MORE_THAN_EQUAL_TO :
      case NUIDBQueryType.NOT_EQUAL :
      case NUIDBQueryType.LIKE :
        return "$fieldName $queryType ?";
      case NUIDBQueryType.IS_NULL :
      case NUIDBQueryType.IS_NOT_NULL :
        return "$fieldName $queryType";
      case NUIDBQueryType.IN : {
        if((value is List) != true) throw Exception("NUIDatabase -> Invalid like query data type");

        List values = value as List;
        String query = "$fieldName $queryType (";
        bool isText = nativeType == NUIDBNativeType.TEXT;
        String inQuery = "";
        for(dynamic d in values){
          if(inQuery.isEmpty){
            inQuery = inQuery + (isText ? "'$d'" : "$d");
          }
          else{
            inQuery = inQuery + ", " + (isText ? "'$d'" : "$d");
          }
        }
        query = query + inQuery + ")";
        return query;
      }
    }
    throw Exception("NUIDatabase -> Invalid query type");
  }
}
